@@ -1,5 +1,5 @@
 /* GKrellM
-|  Copyright (C) 1999-2007 Bill Wilson
+|  Copyright (C) 1999-2009 Bill Wilson
 |
 |  Author:  Bill Wilson    billw@gkrellm.net
 |  Latest versions might be found at:  http://gkrellm.net
@@ -17,6 +17,18 @@
 |
 |  You should have received a copy of the GNU General Public License
 |  along with this program. If not, see http://www.gnu.org/licenses/
+|
+|
+|  Additional permission under GNU GPL version 3 section 7
+|
+|  If you modify this program, or any covered work, by linking or
+|  combining it with the OpenSSL project's OpenSSL library (or a
+|  modified version of that library), containing parts covered by
+|  the terms of the OpenSSL or SSLeay licenses, you are granted
+|  additional permission to convey the resulting work.
+|  Corresponding Source for a non-source form of such a combination
+|  shall include the source code for the parts of OpenSSL used as well
+|  as that of the covered work.
 */
 
 #include "gkrellmd.h"
@@ -965,7 +977,7 @@ gkrellm_net_routed_event(gchar *name, gboolean routed)
 void
 gkrellm_net_add_timer_type_ppp(gchar *name)
 	{
-	if (!_GK.net_timer)
+	if (!_GK.net_timer || !name)
 		return;
 	if (name && !strncmp(_GK.net_timer, name, strlen(name) - 1))
 		net_timer_type = TIMER_TYPE_PPP;
@@ -974,7 +986,7 @@ gkrellm_net_add_timer_type_ppp(gchar *name)
 void
 gkrellm_net_add_timer_type_ippp(gchar *name)
 	{
-	if (!_GK.net_timer)
+	if (!_GK.net_timer || !name)
 		return;
 	if (name && !strncmp(_GK.net_timer, name, strlen(name) - 1))
 		net_timer_type = TIMER_TYPE_IPPP;
@@ -2328,6 +2340,8 @@ gkrellmd_client_read(gint fd, gint nbytes)
 				{
 				mon = (GkrellmdMonitor *) list->data;
 				mp = mon->privat;
+				if (!mp->serve_name)
+					continue;
 				n = strlen(mp->serve_name);
 				e = s + n;
 				if (*e == '>' && !strncmp(mp->serve_name, s, n))
