@@ -1,5 +1,5 @@
 /* GKrellM
-|  Copyright (C) 1999-2008 Bill Wilson
+|  Copyright (C) 1999-2009 Bill Wilson
 |
 |  Author:  Bill Wilson    billw@gkrellm.net
 |  Latest versions might be found at:  http://gkrellm.net
@@ -191,7 +191,8 @@ gkrellm_sensors_add_sensor(gint type, gchar *sensor_path, gchar *id_name,
 /* ======================================================================== */
 static gboolean	use_threads,
 				thread_data_valid,
-				units_fahrenheit;
+				units_fahrenheit,
+				show_units = TRUE;
 
 static gboolean thread_busy;
 
@@ -522,7 +523,12 @@ sensor_read_temperature(Sensor *sensor, gfloat *temp, gchar *units)
 	if (temp)
 		*temp = t;
 	if (units)
-		*units = units_fahrenheit ? 'F':'C';
+		{
+		if (show_units)
+			*units = units_fahrenheit ? 'F':'C';
+	   	else
+			*units = '\0';
+		}
 	if ((_GK.debug_level & DEBUG_SENSORS) && sensor)
 		printf("sensor_temp: %s %s t=%.2f\n",
 					sensor->name_locale, sensor->path, sensor->value);
@@ -1362,7 +1368,10 @@ make_temperature_panel(GtkWidget *vbox, gint first_create)
 		return;
 	style = gkrellm_meter_style(style_id);
 	m = gkrellm_get_style_margins(style);
-	format = units_fahrenheit ? "188.8F" : "88.8C";
+	if (show_units)
+		format = units_fahrenheit ? "188.8F" : "88.8C";
+	else
+		format = units_fahrenheit ? "188.8" : "88.8";
 	assign_textstyles(temperature_list, &ts_name, &ts_sensor, format);
 	gkrellm_get_top_bottom_margins(style, &y, NULL);
 	y += bezel_style->border.top;
@@ -1773,6 +1782,8 @@ save_sensors_config(FILE *f_not_used)
 
 	fprintf(f, "%s units_fahrenheit %d\n", SENSOR_CONFIG_KEYWORD,
 				units_fahrenheit);
+	fprintf(f, "%s show_units %d\n", SENSOR_CONFIG_KEYWORD,
+				show_units);
 	fprintf(f, "%s volt_display_mode %d\n", SENSOR_CONFIG_KEYWORD,
 				display_mode);
 	/* _GK.mbmon_port is handled in config.c so that the port can be
@@ -1807,6 +1818,8 @@ load_sensors_config(gchar *arg)
 		sscanf(item, "%d", &sensor_config_sysdep_private);
 	else if (!strcmp(config, "units_fahrenheit"))
 		sscanf(item, "%d", &units_fahrenheit);
+	else if (!strcmp(config, "show_units"))
+		sscanf(item, "%d", &show_units);
 	else if (!strcmp(config, "volt_display_mode"))
 		sscanf(item, "%d", &display_mode);
 	else if (!strcmp(config, "sensor_float_factor"))
@@ -2588,6 +2601,21 @@ cb_temperature_units(GtkWidget *button, gpointer data)
 	gkrellm_proc_draw_sensors(NULL);
 	}
 
+static void
+cb_show_units(GtkWidget *button, gpointer data)
+	{
+	gint	show;
+
+	show = GTK_TOGGLE_BUTTON(button)->active;
+	if (show == show_units)
+		return;
+	show_units = show;
+
+	gkrellm_sensors_rebuild(DO_TEMP, FALSE, FALSE);
+	gkrellm_cpu_draw_sensors(NULL);
+	gkrellm_proc_draw_sensors(NULL);
+	}
+
 static void
 cb_voltages_display(GtkWidget *entry, gpointer data)
 	{
@@ -2812,6 +2840,10 @@ create_sensors_tab(GtkWidget *tab_vbox)
 				units_fahrenheit, FALSE, FALSE, 0,
 				cb_temperature_units, NULL,
 				_("Display fahrenheit"));
+	gkrellm_gtk_check_button_connected(box, &button,
+				show_units, FALSE, FALSE, 0,
+				cb_show_units, NULL,
+				_("Show units"));
 	if (!sensor_list)
 		gtk_widget_set_sensitive(button, FALSE);
 
@@ -2859,16 +2891,24 @@ create_sensors_tab(GtkWidget *tab_vbox)
 		gtk_label_set_use_markup(GTK_LABEL(label), TRUE);
 		gtk_label_set_markup(GTK_LABEL(label),
 			_("<small>Daemon command must be: <b>mbmon -r -P port</b>\n"
-			  "where 'port' must match the port number entered here:</small>"));
+			 "where 'port' must match the port number entered here:</small>"));
 		gtk_box_pack_start(GTK_BOX(box), label, FALSE, FALSE, 0);
+		hbox = gtk_hbox_new(FALSE, 2);
+		gtk_box_pack_start(GTK_BOX(box), hbox, TRUE, TRUE, 0);
 		entry = gtk_entry_new();
+		gtk_entry_set_max_length(GTK_ENTRY(entry), 6);
 		mbmon_port_entry = entry;
 		if (_GK.mbmon_port > 0)
 			{
 			snprintf(buf, sizeof(buf), "%d", _GK.mbmon_port);
 			gtk_entry_set_text(GTK_ENTRY(entry), buf);
 			}
-		gtk_box_pack_start(GTK_BOX(box), entry, FALSE, FALSE, 4);
+		gtk_box_pack_start(GTK_BOX(hbox), entry, FALSE, FALSE, 4);
+		label = gtk_label_new(
+			_("See the README or do a \"man gkrellm\" for more information.\n"));
+		gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_LEFT);
+		gtk_box_pack_start(GTK_BOX(box), label, FALSE, FALSE, 4);
+
 		g_signal_connect(G_OBJECT(mbmon_port_entry), "activate",
 	                G_CALLBACK(mbmon_port_entry_activate_cb), NULL);
 		}
